@@ -6,6 +6,7 @@ order = [
     'tpDcc.dccs.maya.core.api',
     'tpDcc.dccs.maya.core.helpers',
     'tpDcc.dccs.maya.core.mathutils',
+    'tpDcc.dccs.maya.core.directory',
     'tpDcc.dccs.maya.core.matrix',
     'tpDcc.dccs.maya.core.modelpanel',
     'tpDcc.dccs.maya.core.playblast',
@@ -17,7 +18,7 @@ order = [
     'tpDcc.dccs.maya.core.geometry',
     'tpDcc.dccs.maya.core.mesh',
     'tpDcc.dccs.maya.core.constraint',
-    'tpDcc.dccs.maya.core.component'
-    'tpDcc.dccs.maya.core.ik'
+    'tpDcc.dccs.maya.core.component',
+    'tpDcc.dccs.maya.core.ik',
     'tpDcc.dccs.maya.core.curve'
 ]
